==> webkit2gtk_2.50.1.orig.tar.xz: webkitgtk-2.50.1/Source/WebCore/Modules/webtransport/WebTransportSendStream.h <==
/*
 * Copyright (C) 2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "WritableStream.h"

namespace WebCore {

class DeferredPromise;

struct WebTransportSendStreamStats;

class WebTransportSendStream : public WritableStream {
public:
    static ExceptionOr<Ref<WebTransportSendStream>> create(JSDOMGlobalObject&, Ref<WritableStreamSink>&&);

    void getStats(Ref<DeferredPromise>&&);
    std::optional<int64_t> sendOrder() { return m_sendOrder; }
    void setSendOrder(std::optional<int64_t> order) { m_sendOrder = order; }
private:
    WebTransportSendStream(Ref<InternalWritableStream>&&);

    std::optional<int64_t> m_sendOrder;
};

}

==> webkit2gtk_2.51.1.orig.tar.xz: webkitgtk-2.51.1/Source/WebCore/Modules/webtransport/WebTransportSendStream.h <==
/*
 * Copyright (C) 2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "WritableStream.h"

namespace WebCore {

class DeferredPromise;
class WebTransportSendStreamSink;
class WebTransportSession;

struct WebTransportSendStreamStats;
struct WebTransportStreamIdentifierType;

using WebTransportStreamIdentifier = ObjectIdentifier<WebTransportStreamIdentifierType>;

class WebTransportSendStream : public WritableStream {
public:
    static ExceptionOr<Ref<WebTransportSendStream>> create(WebTransportSession&, JSDOMGlobalObject&, Ref<WebTransportSendStreamSink>&&);
    ~WebTransportSendStream();

    void getStats(ScriptExecutionContext&, Ref<DeferredPromise>&&);
    std::optional<int64_t> sendOrder() { return m_sendOrder; }
    void setSendOrder(std::optional<int64_t> order) { m_sendOrder = order; }
private:
    WebTransportSendStream(WebTransportStreamIdentifier, WebTransportSession&, Ref<InternalWritableStream>&&);

    virtual Type type() const { return Type::WebTransport; }

    const WebTransportStreamIdentifier m_identifier;
    const ThreadSafeWeakPtr<WebTransportSession> m_session;
    std::optional<int64_t> m_sendOrder;
};

}

SPECIALIZE_TYPE_TRAITS_BEGIN(WebCore::WebTransportSendStream)
static bool isType(const WebCore::WritableStream& stream) { return stream.type() == WebCore::WritableStream::Type::WebTransport; }
SPECIALIZE_TYPE_TRAITS_END()
